from pandas import DataFrame as D

# Reindexing / selection / label manipulation

D.f2 = D.rename

## Heads or tails
D.h = D.head
D.t = D.tail

## Duplicates
D.dd = D.drop_duplicates
D.dup = D.duplicated

## Index
D.sx = D.set_index
D.rx = D.reset_index

# Reshaping, Sorting, Transposing

## Sort
D.si = D.sort_index
D.sv = D.sort_values

## Pivot
D.pv = D.pivot
D.pvt = D.pivot_table

# Groupby
D.gb = D.groupby

# Missing data handling
D.dna = D.dropna
D.fna = D.fillna

# Computations / descriptive stats
D.desc = D.describe
D.vc = D.cv = D.value_counts
D.nu = D.nunique

# Properties
D.c = D.columns
D.i = D.index

# IO
D.cb = D.to_clipboard
D.dict = D.to_dict
D.np = D.to_numpy

## File types
D.csv = D.to_csv
D.html = D.to_html
D.json = D.to_json
D.md = D.to_markdown
D.parquet = D.to_parquet
D.xlsx = D.to_excel



from pandas import Series as S

# Reindexing / selection / label manipulation

## Heads or tails
S.h = S.head
S.t = S.tail

## Duplicates
S.dd = S.drop_duplicates
S.dup = S.duplicated

## Index
S.rx = S.reset_index

# Reshaping, Sorting, Transposing

## Sort
S.si = S.sort_index
S.sv = S.sort_values

# Groupby
S.gb = S.groupby

# Missing data handling
S.dna = S.dropna
S.fna = S.fillna

# Computations / descriptive stats
S.vc = S.cv = S.value_counts
S.nu = S.nunique
S.u = S.unique

# Properties
S.i = S.index

# IO
S.cb = S.to_clipboard
S.dict = S.to_dict
S.list = S.to_list
S.np = S.to_numpy

## File types
S.csv = S.to_csv
S.json = S.to_json
S.md = S.to_markdown
S.xlsx = S.to_excel



import pandas as pd

pd.df = pd.DataFrame

# IO
pd.csv = pd.read_csv
pd.json = pd.read_json
pd.parquet = pd.read_parquet
pd.sql = pd.read_sql
pd.xlsx = pd.read_excel


# General function - Pivot
pd.pv = pd.pivot
pd.pvt = pd.pivot_table


# General function - datetime
pd.tdt = pd.to_datetime
pd.ttd = pd.to_timedelta



import numpy as np
import pandas as pd
from pandas import DataFrame as D
from pandas import Series as S


def _style_base(df, r=50, c=50, na_rep="-"):
    if r > len(df):
        _df = df.iloc[:, :c]
    else:
        _df = df.iloc[np.r_[0 : int(r / 2), -int(r / 2) : 0], :c]
    _df_numeric = _df.select_dtypes(include=np.number)
    column_format = {k: "{:0,.2f}" for k in _df_numeric.columns}
    return _df.style.format(column_format, na_rep=na_rep)


def style_heatmap(df, r=50, c=50, na_rep="-", colormap="YlOrRd"):
    base = _style_base(df, r=r, c=c, na_rep=na_rep)
    return base.background_gradient(cmap=colormap)


def style_bar(df, r=50, c=50, na_rep="-", width=50, bar_color="#d65f5f"):
    base = _style_base(df, r=r, c=c, na_rep=na_rep)
    return base.bar(color=bar_color, align="left", width=width)


D.sh = style_heatmap
D.sb = style_bar


try:
    from IPython.display import HTML

    def dataframe_view(df: pd.DataFrame, r=50, c=50) -> HTML:
        html = df.to_html(
            max_rows=r,
            max_cols=c,
            justify="left",
            show_dimensions=True,
        )
        return HTML(html)

except ModuleNotFoundError:

    def dataframe_view(df: pd.DataFrame, r=50, c=50) -> None:
        string = df.to_string(
            max_rows=r,
            max_cols=c,
            justify="left",
            show_dimensions=True,
        )
        return print(string)


def series_view(series: pd.Series, r=50) -> None:
    string = series.to_string(
        name=True,
        length=True,
        dtype=True,
        max_rows=r,
    )
    print(string)


D.v = dataframe_view
S.v = series_view
